ReMAP. Integrated Fleet Mangament solution aimed at replacing fixed-interval inspections with adaptive condition-based interventions.

This python module is part of the ReMAP platform.

The ReMAP platform is free software: you can redistribute it
and/or modify it under the terms of GNU GPL v3.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT ANY WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT,
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN ACTION OF CONTRACT, TORT
OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

This module enables algorithms/models developers to get access to airline
data and metadata created, it's used to send the output of the algorithm
to the ReMAP platform